Uses of Class
com.testingbot.models.TestingbotBrowser
-
Packages that use TestingbotBrowser Package Description com.testingbot.models Plain Gson-mapped POJOs for the TestingBot REST API resources.com.testingbot.testingbotrest Entry point for the TestingBot REST API Java client. -
-
Uses of TestingbotBrowser in com.testingbot.models
Methods in com.testingbot.models that return types with arguments of type TestingbotBrowser Modifier and Type Method Description java.util.List<TestingbotBrowser>TestingbotLabTest. getBrowsers()Method parameters in com.testingbot.models with type arguments of type TestingbotBrowser Modifier and Type Method Description voidTestingbotLabTest. setBrowsers(java.util.List<TestingbotBrowser> browsers) -
Uses of TestingbotBrowser in com.testingbot.testingbotrest
Methods in com.testingbot.testingbotrest that return types with arguments of type TestingbotBrowser Modifier and Type Method Description java.util.ArrayList<TestingbotBrowser>TestingbotREST. getBrowsers()Gets list of available browsers from TestingBotjava.util.List<TestingbotBrowser>TestingbotREST. getLabSuiteBrowsers(int suiteId)Gets the browsers configured for a Codeless suite.java.util.List<TestingbotBrowser>TestingbotREST. getLabTestBrowsers(int labTestId)Gets the browsers configured for a Codeless test.
-