Uses of Class
com.testingbot.models.TestingbotDevice
-
Packages that use TestingbotDevice Package Description com.testingbot.testingbotrest Entry point for the TestingBot REST API Java client. -
-
Uses of TestingbotDevice in com.testingbot.testingbotrest
Methods in com.testingbot.testingbotrest that return TestingbotDevice Modifier and Type Method Description TestingbotDeviceTestingbotREST. getDevice(int deviceId)Retrieves Real Mobile Devices on TestingBotMethods in com.testingbot.testingbotrest that return types with arguments of type TestingbotDevice Modifier and Type Method Description java.util.List<TestingbotDevice>TestingbotREST. getAvailableDevices()Retrieves the currently available Real Mobile Devices on TestingBot.java.util.List<TestingbotDevice>TestingbotREST. getAvailableDevices(int offset, int count)Retrieves available Real Mobile Devices on TestingBotjava.util.List<TestingbotDevice>TestingbotREST. getDevices(int offset, int count)Retrieves Real Mobile Devices on TestingBot This includes devices not currently availablejava.util.List<TestingbotDevice>TestingbotREST. getDevices(java.lang.String platform, java.lang.Boolean web)Retrieves Real Mobile Devices on TestingBot, filtered by platform.
-