Uses of Class
com.testingbot.models.TestingbotTest
-
Packages that use TestingbotTest Package Description com.testingbot.models Plain Gson-mapped POJOs for the TestingBot REST API resources.com.testingbot.testingbotrest Entry point for the TestingBot REST API Java client. -
-
Uses of TestingbotTest in com.testingbot.models
Methods in com.testingbot.models that return types with arguments of type TestingbotTest Modifier and Type Method Description java.util.ArrayList<TestingbotTest>TestingbotTestBuildCollection. getData()java.util.ArrayList<TestingbotTest>TestingbotTestCollection. getData()Method parameters in com.testingbot.models with type arguments of type TestingbotTest Modifier and Type Method Description voidTestingbotTestBuildCollection. setData(java.util.ArrayList<TestingbotTest> data)voidTestingbotTestCollection. setData(java.util.ArrayList<TestingbotTest> data) -
Uses of TestingbotTest in com.testingbot.testingbotrest
Methods in com.testingbot.testingbotrest that return TestingbotTest Modifier and Type Method Description TestingbotTestTestingbotREST. getTest(java.lang.String sessionID)Gets information from TestingBot for a test with sessionIDMethods in com.testingbot.testingbotrest that return types with arguments of type TestingbotTest Modifier and Type Method Description java.lang.Iterable<TestingbotTest>TestingbotREST. iterateTests(int pageSize)Lazily iterates over all tests, paging through the API behind the scenes.java.lang.Iterable<TestingbotTest>TestingbotREST. iterateTests(int pageSize, java.util.Map<java.lang.String,java.lang.String> filters)Lazily iterates over all tests matching the given filters, paging behind the scenes.Methods in com.testingbot.testingbotrest with parameters of type TestingbotTest Modifier and Type Method Description booleanTestingbotREST. updateTest(TestingbotTest test)Updates a Test with sessionID (Selenium sessionID)
-