C D G I K S T U
All Classes All Packages
All Classes All Packages
All Classes All Packages
C
- com.testingbot.models - package com.testingbot.models
- com.testingbot.testingbotrest - package com.testingbot.testingbotrest
D
- deleteStorageFile(String) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Delete a file previously uploaded TestingBot Storage
- deleteTest(String) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Deletes a Test with sessionID (Selenium sessionID)
- deleteTunnel(String) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Deletes a Tunnel with tunnel ID
G
- getAppUrl() - Method in class com.testingbot.models.TestingBotStorageFile
- getAppUrl() - Method in class com.testingbot.models.TestingbotStorageUploadResponse
- getAuthenticationHash() - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Calculates the authentication hash for the current user https://testingbot.com/support/other/sharing
- getAuthenticationHash(String) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Calculates the authentication hash for a specific identifier (sessionId/build-identifier) https://testingbot.com/support/other/sharing
- getBrowser() - Method in class com.testingbot.models.TestingbotTest
- getBrowsers() - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Gets list of available browsers from TestingBot
- getBrowserVersion() - Method in class com.testingbot.models.TestingbotTest
- getBuild() - Method in class com.testingbot.models.TestingbotTest
- getBuildIdentifier() - Method in class com.testingbot.models.TestingbotBuild
- getBuilds(int, int) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Get test builds
- getCity() - Method in class com.testingbot.models.TestingbotUser
- getCompany() - Method in class com.testingbot.models.TestingbotUser
- getCompletedDate() - Method in class com.testingbot.models.TestingbotTest
- getCountry() - Method in class com.testingbot.models.TestingbotUser
- getCreatedAtDate() - Method in class com.testingbot.models.TestingbotBuild
- getCreatedDate() - Method in class com.testingbot.models.TestingBotStorageFile
- getCreatedDate() - Method in class com.testingbot.models.TestingbotTest
- getData() - Method in class com.testingbot.models.TestingbotBuildCollection
- getData() - Method in class com.testingbot.models.TestingBotStorageFileCollection
- getData() - Method in class com.testingbot.models.TestingbotTestBuildCollection
- getData() - Method in class com.testingbot.models.TestingbotTestCollection
- getDeviceName() - Method in class com.testingbot.models.TestingbotBrowser
- getDuration() - Method in class com.testingbot.models.TestingbotTest
- getExtra() - Method in class com.testingbot.models.TestingbotTest
- getFirstName() - Method in class com.testingbot.models.TestingbotUser
- getGroups() - Method in class com.testingbot.models.TestingbotTest
- getId() - Method in class com.testingbot.models.TestingbotBrowser
- getId() - Method in class com.testingbot.models.TestingbotBuild
- getId() - Method in class com.testingbot.models.TestingBotStorageFile
- getId() - Method in class com.testingbot.models.TestingbotTunnel
- getIp() - Method in class com.testingbot.models.TestingbotTunnel
- getLastLoginDate() - Method in class com.testingbot.models.TestingbotUser
- getLastName() - Method in class com.testingbot.models.TestingbotUser
- getLogs() - Method in class com.testingbot.models.TestingbotTest
- getLongVersion() - Method in class com.testingbot.models.TestingbotBrowser
- getMaxConcurrent() - Method in class com.testingbot.models.TestingbotUser
- getMeta() - Method in class com.testingbot.models.TestingbotBuildCollection
- getMeta() - Method in class com.testingbot.models.TestingBotStorageFileCollection
- getMeta() - Method in class com.testingbot.models.TestingbotTestBuildCollection
- getMeta() - Method in class com.testingbot.models.TestingbotTestCollection
- getName() - Method in class com.testingbot.models.TestingbotBrowser
- getName() - Method in class com.testingbot.models.TestingbotTest
- getOs() - Method in class com.testingbot.models.TestingbotTest
- getPlan() - Method in class com.testingbot.models.TestingbotUser
- getPlatform() - Method in class com.testingbot.models.TestingbotBrowser
- getPlatformName() - Method in class com.testingbot.models.TestingbotBrowser
- getPrivateIp() - Method in class com.testingbot.models.TestingbotTunnel
- getRequestedAt() - Method in class com.testingbot.models.TestingbotTunnel
- getSeconds() - Method in class com.testingbot.models.TestingbotUser
- getSessionId() - Method in class com.testingbot.models.TestingbotTest
- getState() - Method in class com.testingbot.models.TestingbotTest
- getState() - Method in class com.testingbot.models.TestingbotTunnel
- getStatusMessage() - Method in class com.testingbot.models.TestingbotTest
- getStorageFile(String) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Retrieves meta-data from a TestingBot Storage file
- getStorageFiles(int, int) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Retrieves meta-data for TestingBot Storage files
- getStreet() - Method in class com.testingbot.models.TestingbotUser
- getTest(String) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Gets information from TestingBot for a test with sessionID
- getTests(int, int) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Get latest tests
- getTestsForBuild(String) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Gets tests for a specific build from TestingBot
- getThumbs() - Method in class com.testingbot.models.TestingbotTest
- getTunnels() - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Gets assigned tunnels for your account on TestingBot
- getType() - Method in class com.testingbot.models.TestingBotStorageFile
- getType() - Method in class com.testingbot.models.TestingbotTest
- getUpdatedAtDate() - Method in class com.testingbot.models.TestingbotBuild
- getUrl() - Method in class com.testingbot.models.TestingBotStorageFile
- getUserInfo() - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Gets information from TestingBot for your user account
- getVat() - Method in class com.testingbot.models.TestingbotUser
- getVersion() - Method in class com.testingbot.models.TestingbotBrowser
- getVideo() - Method in class com.testingbot.models.TestingbotTest
I
- isSuccess() - Method in class com.testingbot.models.TestingbotTest
K
- key - Variable in class com.testingbot.testingbotrest.TestingbotREST
-
The key to use when performing HTTP requests to the TestingBot REST API.
S
- secret - Variable in class com.testingbot.testingbotrest.TestingbotREST
-
The secret key to use when performing HTTP requests to the TestingBot REST API.
- setAppUrl(String) - Method in class com.testingbot.models.TestingBotStorageFile
- setAppUrl(String) - Method in class com.testingbot.models.TestingbotStorageUploadResponse
- setBrowser(String) - Method in class com.testingbot.models.TestingbotTest
- setBrowserVersion(String) - Method in class com.testingbot.models.TestingbotTest
- setBuild(String) - Method in class com.testingbot.models.TestingbotTest
- setBuildIdentifier(String) - Method in class com.testingbot.models.TestingbotBuild
- setCity(String) - Method in class com.testingbot.models.TestingbotUser
- setCompany(String) - Method in class com.testingbot.models.TestingbotUser
- setCompletedDate(String) - Method in class com.testingbot.models.TestingbotTest
- setCountry(String) - Method in class com.testingbot.models.TestingbotUser
- setCreatedAtDate(String) - Method in class com.testingbot.models.TestingbotBuild
- setCreatedDate(String) - Method in class com.testingbot.models.TestingBotStorageFile
- setCreatedDate(String) - Method in class com.testingbot.models.TestingbotTest
- setData(ArrayList<TestingbotBuild>) - Method in class com.testingbot.models.TestingbotBuildCollection
- setData(ArrayList<TestingBotStorageFile>) - Method in class com.testingbot.models.TestingBotStorageFileCollection
- setData(ArrayList<TestingbotTest>) - Method in class com.testingbot.models.TestingbotTestBuildCollection
- setData(ArrayList<TestingbotTest>) - Method in class com.testingbot.models.TestingbotTestCollection
- setDeviceName(String) - Method in class com.testingbot.models.TestingbotBrowser
- setDuration(int) - Method in class com.testingbot.models.TestingbotTest
- setExtra(String) - Method in class com.testingbot.models.TestingbotTest
- setFirstName(String) - Method in class com.testingbot.models.TestingbotUser
- setGroups(ArrayList<String>) - Method in class com.testingbot.models.TestingbotTest
- setId(int) - Method in class com.testingbot.models.TestingbotBrowser
- setId(int) - Method in class com.testingbot.models.TestingbotBuild
- setId(int) - Method in class com.testingbot.models.TestingBotStorageFile
- setId(int) - Method in class com.testingbot.models.TestingbotTunnel
- setIp(String) - Method in class com.testingbot.models.TestingbotTunnel
- setLastLoginDate(String) - Method in class com.testingbot.models.TestingbotUser
- setLastName(String) - Method in class com.testingbot.models.TestingbotUser
- setLogs(Map<String, String>) - Method in class com.testingbot.models.TestingbotTest
- setLongVersion(String) - Method in class com.testingbot.models.TestingbotBrowser
- setMaxConcurrent(int) - Method in class com.testingbot.models.TestingbotUser
- setMeta(HashMap<String, Integer>) - Method in class com.testingbot.models.TestingbotBuildCollection
- setMeta(HashMap<String, Integer>) - Method in class com.testingbot.models.TestingBotStorageFileCollection
- setMeta(HashMap<String, Integer>) - Method in class com.testingbot.models.TestingbotTestBuildCollection
- setMeta(HashMap<String, Integer>) - Method in class com.testingbot.models.TestingbotTestCollection
- setName(String) - Method in class com.testingbot.models.TestingbotBrowser
- setName(String) - Method in class com.testingbot.models.TestingbotTest
- setOs(String) - Method in class com.testingbot.models.TestingbotTest
- setPlan(String) - Method in class com.testingbot.models.TestingbotUser
- setPlatform(String) - Method in class com.testingbot.models.TestingbotBrowser
- setPlatformName(String) - Method in class com.testingbot.models.TestingbotBrowser
- setPrivateIp(String) - Method in class com.testingbot.models.TestingbotTunnel
- setRequestedAt(String) - Method in class com.testingbot.models.TestingbotTunnel
- setSeconds(int) - Method in class com.testingbot.models.TestingbotUser
- setSessionId(String) - Method in class com.testingbot.models.TestingbotTest
- setState(String) - Method in class com.testingbot.models.TestingbotTest
- setState(String) - Method in class com.testingbot.models.TestingbotTunnel
- setStatusMessage(String) - Method in class com.testingbot.models.TestingbotTest
- setStreet(String) - Method in class com.testingbot.models.TestingbotUser
- setSuccess(boolean) - Method in class com.testingbot.models.TestingbotTest
- setThumbs(ArrayList<String>) - Method in class com.testingbot.models.TestingbotTest
- setType(String) - Method in class com.testingbot.models.TestingBotStorageFile
- setType(String) - Method in class com.testingbot.models.TestingbotTest
- setUpdatedAtDate(String) - Method in class com.testingbot.models.TestingbotBuild
- setUrl(String) - Method in class com.testingbot.models.TestingBotStorageFile
- setVat(String) - Method in class com.testingbot.models.TestingbotUser
- setVersion(String) - Method in class com.testingbot.models.TestingbotBrowser
- setVideo(String) - Method in class com.testingbot.models.TestingbotTest
- stopTest(String) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Stops a Test with sessionID (Selenium sessionID)
T
- TestingbotApiException - Exception in com.testingbot.testingbotrest
- TestingbotBrowser - Class in com.testingbot.models
- TestingbotBrowser() - Constructor for class com.testingbot.models.TestingbotBrowser
- TestingbotBuild - Class in com.testingbot.models
- TestingbotBuild() - Constructor for class com.testingbot.models.TestingbotBuild
- TestingbotBuildCollection - Class in com.testingbot.models
- TestingbotBuildCollection() - Constructor for class com.testingbot.models.TestingbotBuildCollection
- TestingbotREST - Class in com.testingbot.testingbotrest
-
Simple Java API that invokes the TestingBot REST API.
- TestingbotREST(String, String) - Constructor for class com.testingbot.testingbotrest.TestingbotREST
-
Constructs a new instance of the TestingBotREST class.
- TestingBotStorageFile - Class in com.testingbot.models
- TestingBotStorageFile() - Constructor for class com.testingbot.models.TestingBotStorageFile
- TestingBotStorageFileCollection - Class in com.testingbot.models
- TestingBotStorageFileCollection() - Constructor for class com.testingbot.models.TestingBotStorageFileCollection
- TestingbotStorageUploadResponse - Class in com.testingbot.models
- TestingbotStorageUploadResponse() - Constructor for class com.testingbot.models.TestingbotStorageUploadResponse
- TestingbotTest - Class in com.testingbot.models
- TestingbotTest() - Constructor for class com.testingbot.models.TestingbotTest
- TestingbotTestBuildCollection - Class in com.testingbot.models
- TestingbotTestBuildCollection() - Constructor for class com.testingbot.models.TestingbotTestBuildCollection
- TestingbotTestCollection - Class in com.testingbot.models
- TestingbotTestCollection() - Constructor for class com.testingbot.models.TestingbotTestCollection
- TestingbotTunnel - Class in com.testingbot.models
- TestingbotTunnel() - Constructor for class com.testingbot.models.TestingbotTunnel
- TestingbotUnauthorizedException - Exception in com.testingbot.testingbotrest
- TestingbotUnauthorizedException() - Constructor for exception com.testingbot.testingbotrest.TestingbotUnauthorizedException
- TestingbotUser - Class in com.testingbot.models
- TestingbotUser() - Constructor for class com.testingbot.models.TestingbotUser
U
- updateTest(TestingbotTest) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Updates a Test with sessionID (Selenium sessionID)
- updateTest(String, Map<String, Object>) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Updates a Test with sessionID (Selenium sessionID)
- uploadToStorage(File) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Upload file to TestingBot Storage
- uploadToStorage(String) - Method in class com.testingbot.testingbotrest.TestingbotREST
-
Upload file to TestingBot Storage
All Classes All Packages